pyttsx - Text-to-speech x-platform — pyttsx v1.0 documentation

### Navigation

- index
- modules |
- next |
- pyttsx v1.0 documentation »

# pyttsx - Text-to-speech x-platform

This documentation describes the pyttsx Python package v 1.0 and was rendered on November 08, 2009.

Table of Contents

- Supported synthesizers
- Using pyttsx
  - The Engine factory
  - The Engine interface
  - The Voice metadata
  - Examples
- Implementing drivers
  - The Driver interface
  - The DriverProxy interface
- Changelog
  - Version 1.0

Project Links

- Project home page at Launchpad
- Package listing in PyPI
- Documentation in PyPI

### Navigation

- index
- modules |
- next |
- pyttsx v1.0 documentation »